#!/bin/sh -f
if [ "`uname`" = "Linux" ]; then enable -n echo; fi
#*******************************************************************************
# E.S.O. - VLT project
#
# "@(#) $Id: fims.sh 234602 2012-10-29 12:55:55Z pbaksai $"
#
# who       when        what
# --------  ----------  --------------------------------------------------------
# pbaksai   2012/09/22  PPRS-23355: Updated for new product package structure
#                       - New location of FORS*.isf to config/.
# pbaksai   2011/11/16  Updated for SVN versioning
# pbaksai   2010/12/03  Added FC plugin
# pbaksai   2010/11/17  Renamed PE_SkyCat_plugin to GraphFeatures_plugin
# pbaksai   2009/06/02  PPRS-27204: Removed SCREEN
# pbaksai   2008/06/23  PPRS-27337: Support for FORS2+1
# pbaksai   2007/09/20  Added SCREEN option
# pbaksai   2007/05/25  PPRS-23868: P80 IP
# mkiekebu  31/03/01    for fims 2.29
# aaguayo   14/03/01    for fims 2.28 (use of SKYCAT_VER variable)
# hummel    27/01/99    for fims 1.3.0
# hummel    12/01/99    for fims 1.2.7
# hummel    07/01/99    for fims 1.2.6
# hummel    04/01/99    Edit this file (lines 100-110)
# wgaessle  18/07/98    deleted eso examples, changed FORS_OSS_ROOT to
#                       FIMSROOT same for INS_ROOT. Set path for file
#                       loaded with skycat to $INS_ROOT/SYSTEM/COMMON/
#                       PREPARATION
# hummel    09/07/98    Created
#
#*******************************************************************************
#   NAME
#       fims.sh - startup shell script for FIMS
#
#   SYNOPSIS
#       fims.sh
#       fims.sh "<skycat command line options>" [DEBUG]
#
#   DESCRIPTION
#       This shell script sets all relevant UNIX environment variables
#       to plugin the FIMS module to the ESO SkyCat Tool
#       This scripts has three parts
#       1) set the site-dependent environment variables
#       2) check if everything is found
#       3) start skycat with some command line options
#       For FIMS installation edit 1) according to your local site preferences
#
#   FILES
#       fims.sh
#
#   ENVIRONMENT
#       HP-UX-10.20, OSF, SunOs, Linux
#       SkyCat Tool V2.2
#
#   RETURN VALUES
#       none
#
#   CAUTIONS
#       skycat command line options have to be included in double quotes
#
#   EXAMPLES
#       usage: fims.sh <"SkyCat command line parameter"> <DEBUG>
#       examples :
#
#       fims.sh                         (Plain start)
#       fims.sh ""                      (no skycat option, as example before)
#       fims.sh "-float_panel 1 -rtd 1" (with skycat options)
#       fims.sh "-withscrollbars"
#       fims.sh "-file $HOME/FITS/ngc0815.fits -catalog $HOME/cat/gsc0815.ptl"
#       fims.sh "-rtd 1 -with_grid 1 -scrollbars 1 -float_panel 1"
#       fims.sh "" DEBUG                (shows detailed environments,
#                                        use this option to verify installation)
#
#   SEE ALSO
#       FIMS Installation Guide
#       fims_ec.tcl
#
#   BUGS
#
#-------------------------------------------------------------------------------
#
# ------------- Part 1 set environments ------------------

if [ "`uname`" = "Linux" ]; then
     remote=rsh
elif [ "`uname`" = "HP-UX" ]; then
     remote=remsh
else
     remote=remsh
fi

# default command line options for skycat
CLS="-with_grid 1 -scrollbars 1 -rtd 0"

# command line options for skycat
CLO=${1:-$CLS}
# strip quotes from strings coming from GPS shell
CLO=`echo $CLO | sed "s/\"//g"`

# private="-file /usr3/hummel/FITS/ngc330-1/COM26_NGC330_0.be.2.fits"
# private="-file /home/hummel/FITS/GaTi_22/V500Aql.fits"
# private="-file /home/hummel/FITS/COM26_NGC330_0.be.2.fits"
# private="-float_panel 1 -catalog /home/hummel/FITS/COMM2/../FITS/ngc330-1/total.ptl -file /home/hummel/FITS/COMM2/../FITS/ngc330-1/COM26_NGC330_0.be.2.fits"

# default debug option
DB=${2:-OFF}
if [ $DB == OFF ]; then DB=false; else DB=true; fi

if $DB; then echo " CLO                 = $CLO     "; fi
if $DB; then echo " DISPLAY             = $DISPLAY "; fi

echo

# any other workstation outside the VLT - FORS environment

FIMSROOT=${FIMSROOT:-$HOME/fims};  export FIMSROOT; # where fims is installed
ISF_DIR=$FIMSROOT/config;          export ISF_DIR;  # FORS1.isf from FIMS packg
INS_ROOT=$HOME;                    export INS_ROOT; # user home directory
INS_USER=.fims;                    export INS_USER; # fims output dir
PREP_DIR=$INS_ROOT/$INS_USER/PREP; export PREP_DIR; # where is the fits file
LOG_DIR=$INS_ROOT/$INS_USER/LOG;   export LOG_DIR;  # keep this
SET_DIR=$INS_ROOT/$INS_USER/SET;   export SET_DIR;  # keep this

# copy the MXU standard masks to the SET directory
echo "Remember to copy any MXU technical masks to $SET_DIR"

# cp $FIMSROOT/src/mxu2.???.standard.fad $SET_DIR/.
# chmod +w $SET_DIR/mxu2.???.standard.fad

# The FORS1.isf file can be either from the on-line database (Paranal)
# from the FIMS package (must be updated each observing period)
# or from the P2PP FORS1-Instrument-Package (also updated)

# Find out component versions
if [ -n $SVNREPO ]; then
    # When in a SVN environment, update version info
    echo `svn info $FIMSROOT/.` > $FIMSROOT/svninfo.txt
fi
if [ -a $FIMSROOT/svninfo.txt ]; then
    SVN_INFO=`cat $FIMSROOT/svninfo.txt`
else
    SVN_INFO="Path: unknown URL: unknown Repository Root: unknown Repository UUID: 00000000-0000-0000-0000-000000000000 Revision: 000000 Node Kind: directory Schedule: normal Last Changed Author: unknown Last Changed Rev: 000000 Last Changed Date: 0000-00-00 00:00:00 +0000 (Dow, 00 Mon 0000)"
fi

if [ -z "$MOD_VERSION" ]; then
    # MOD_VERSION=`svnversion $FIMSROOT/.`; export MOD_VERSION
    MOD_VERSION=`echo $SVN_INFO | awk '/Last Changed Rev:/{printf("%s", $25)}'`; export MOD_VERSION
    MOD_DATE=`echo $SVN_INFO | awk '/Last Changed Date:/{printf("%s", $29)}'`
    MOD_TIME=`echo $SVN_INFO | awk '/Last Changed Date:/{printf("%s", $30)}'`
fi
M_V=$MOD_VERSION

if [ -z "$SKYCAT_VER" ]; then
    SKYCAT_VER=2.7.3; export SKYCAT_VER
fi
S_V=$SKYCAT_VER


# -------------------- PART 2 -- check settings -----------------

if [ -d $FIMSROOT ]
   then
   if $DB; then echo " FIMSROOT            = $FIMSROOT"; fi
   else echo "ERROR: >$FIMSROOT< does not exist"
        echo ">>>>>hint:"
        echo "setenv FIMSROOT <..>/fims (your FIMS installation directory)"
        echo "FIMSROOT=<..>/fims; export FIMSROOT (for bash)"
        echo "setenv FIMSROOT ${PWD}/.."
        exit
fi

if [ -d $INS_ROOT ]
   then
   if $DB; then echo " INS_ROOT            = $INS_ROOT"; fi
   else echo "ERROR: $INS_ROOT does not exist"
        mkdir $INS_ROOT
        echo "created ----- $INS_ROOT"
fi

if [ -d $INS_ROOT/$INS_USER ]
   then
   if $DB; then echo " INS_ROOT/INS_USER   = $INS_ROOT/$INS_USER"; fi
   else echo "ERROR: >$INS_ROOT/$INS_USER< does not exist"
        mkdir $INS_ROOT/$INS_USER
        echo "created ----- $INS_ROOT/$INS_USER"
fi

# where to write the target setup files
# -------------------------------------
if [ -d $SET_DIR ]
   then
   if $DB; then echo " SET_DIR             = $SET_DIR"; fi
   else echo "ERROR: >$SET_DIR< does not exist"
        mkdir $SET_DIR
        echo "created ----- $SET_DIR"
fi

# where to write the FIMS log files
# -------------------------------------
if [ -d $LOG_DIR ]
   then
   if $DB; then echo " LOG_DIR             = $LOG_DIR"; fi
   else echo "ERROR: >$LOG_DIR< does not exist"
        mkdir $LOG_DIR
        echo "created ----- $LOG_DIR"
fi

# from where to load the fits files
# -------------------------------------
if [ -d $PREP_DIR ]
   then
   if $DB; then echo " PREP_DIR            = $PREP_DIR"; fi
   else echo "ERROR: >$PREP_DIR< does not exist"
        mkdir $PREP_DIR
        echo "created ----- $PREP_DIR"
fi



if [ -d $ISF_DIR ]; then
    if $DB; then
        echo " ISF_DIR             = $ISF_DIR"; 
    fi
else 
    echo "ERROR: >$ISF_DIR< does not exist"
    ISF_DIR=$FIMSROOT/config
    if [ -d $ISF_DIR ]; then
         echo "found: >$ISF_DIR< (FIMS internal)"
    else 
         echo "FIMS Installation Error"
         echo ">>>>>hint:"
         echo "make"
         exit
    fi
fi

#-------------- P L U G I N S -------------------------------
        ESO_PLUG=$FIMSROOT/lib/libesoPlugins.tcl;
       FIMS_PLUG=$FIMSROOT/lib/libfimsPlugins.tcl;
       FRTD_PLUG=$FIMSROOT/lib/libfrtdPlugins.tcl;
         FC_PLUG=$FIMSROOT/../lib/libfcPlugins.tcl;

      RTD_PLUGIN=$FRTD_PLUG/Rtd_plugin.tcl;       export RTD_PLUGIN
SKYSEARCH_PLUGIN=$FIMS_PLUG/SkySearch_plugin.tcl; export SKYSEARCH_PLUGIN
   SKYCAT_PLUG01=$FIMS_PLUG/SkyCat_plugin.tcl;
   SKYCAT_PLUG02=$ESO_PLUG/GraphFeatures_plugin.tcl;
   SKYCAT_PLUG03=$FC_PLUG/FindingChart_plugin.tcl;

if $DB; then
    echo
    echo " ESO_PLUG            = $ESO_PLUG"
    echo
    #echo " RTD_PLUGIN          = $RTD_PLUGIN"
    echo " SKYSEARCH_PLUGIN    = $SKYSEARCH_PLUGIN"
    echo " SKYCAT_PLUG01       = $SKYCAT_PLUG01"
    echo " SKYCAT_PLUG02       = $SKYCAT_PLUG02"
    echo " SKYCAT_PLUG03       = $SKYCAT_PLUG03"
    echo
    echo " Test if files exist"
    echo
    if [ -f $SKYSEARCH_PLUGIN ]; then 
        echo " found: $SKYSEARCH_PLUGIN"
    else
        echo " where? $SKYSEARCH_PLUGIN"
    fi
    # if [ -f $RTD_PLUGIN ]; then
    #      echo " found: $RTD_PLUGIN"
    # else
    #      echo " where? $RTD_PLUGIN"
    # fi
    if [ -f $SKYCAT_PLUG01 ]; then
        echo " found: $SKYCAT_PLUG01"
    else
        echo " where? $SKYCAT_PLUG01"
    fi
    if [ -f $SKYCAT_PLUG02 ]; then
        echo " found: $SKYCAT_PLUG02"
    else
        echo " where? $SKYCAT_PLUG02"
    fi
    if [ -f $SKYCAT_PLUG03 ]; then
        echo " found: $SKYCAT_PLUG03"
    else
        echo " where? $SKYCAT_PLUG03"
    fi
    echo
fi

# join all plugins to one single keyword
SKYCAT_PLUGIN=$SKYCAT_PLUG03:$SKYCAT_PLUG02:$SKYCAT_PLUG01; export SKYCAT_PLUGIN

if $DB; then echo " SKYCAT_PLUGIN       = >$SKYCAT_PLUGIN<"; fi

# ----------------------------
# print current version number
# ----------------------------
echo
echo
echo
echo "  W E L C O M E     T O     F I M S"
echo " -----------------------------------"
echo
echo " +----------------+                +---------------------+"
echo "" | awk -v MV=$M_V -v SV=$S_V '{ printf(" | FIMS  %8s |----plugin----> | SkyCatTool %8s |\n", MV, SV) }'
echo " +----------------+                +---------------------+"

echo
echo " +------------------------------------------+"
echo "" | awk -v MD=$MOD_DATE -v MT=$MOD_TIME '{ printf(" | last checkin : %s GD %s UT", MD, MT) }'
echo " | INPUT : "$PREP_DIR
echo " | now is       : "`date -u +%Y-%m-%d`" GD "`date -u +%H:%M:%S`" UT | OUTPUT: "$SET_DIR
echo " | FIMS requires: SkyCat "$S_V"              | LOGS  :" $LOG_DIR
echo " +------------------------------------------+"
echo


# ------------------ PART 3 --- start skycat ------------------
echo

echo "skycat $CLO $private ..."

# call skycat

skycat $CLO $private

#
#___oOo___
